@@ -3,7 +3,7 @@ package App::ModuleBuildTiny;
 use 5.014;
 use strict;
 use warnings;
-our $VERSION = '0.032';
+our $VERSION = '0.033';
 
 use Exporter 5.57 'import';
 our @EXPORT = qw/modulebuildtiny/;
@@ -16,7 +16,7 @@ use ExtUtils::Manifest qw/manifind maniskip maniread/;
 use File::Basename qw/dirname/;
 use File::Path qw/mkpath/;
 use File::Slurper qw/write_text write_binary read_binary/;
-use File::Spec::Functions qw/catfile catdir rel2abs/;
+use File::Spec::Functions qw/catfile catdir curdir rel2abs/;
 use Getopt::Long 2.36 'GetOptionsFromArray';
 use JSON::PP qw/decode_json/;
 use Module::Runtime 'require_module';
@@ -144,8 +144,16 @@ my %actions = (
 		$AUTHOR_TESTING = 1;
 		GetOptionsFromArray(\@arguments, 'release!' => \$RELEASE_TESTING, 'author!' => \$AUTHOR_TESTING, 'automated!' => \$AUTOMATED_TESTING,
 			'extended!' => \$EXTENDED_TESTING, 'non-interactive!' => \$NONINTERACTIVE_TESTING) or return 2;
+		my @dirs = 't';
+		if ($AUTHOR_TESTING) {
+			push @dirs, catdir('xt', 'author');
+			push @dirs, glob 'xt/*.t';
+		}
+		push @dirs, catdir('xt', 'release') if $RELEASE_TESTING;
+		push @dirs, catdir('xt', 'extended') if $EXTENDED_TESTING;
+		@dirs = grep -e, @dirs;
 		my $dist = App::ModuleBuildTiny::Dist->new;
-		return $dist->run(command => [ $Config{perlpath}, 'Build', 'test' ], build => 1);
+		return $dist->run(command => [ 'prove', '-br', @dirs ], build => 1, verbose => 1);
 	},
 	upload => sub {
 		my @arguments = @_;
@@ -155,7 +163,7 @@ my %actions = (
 		$dist->check_changes;
 		$dist->check_meta;
 		local ($AUTHOR_TESTING, $RELEASE_TESTING) = (1, 1);
-		$dist->run(command => [ $Config{perlpath}, 'Build', 'test' ], build => 1) or return 1;
+		$dist->run(command => [ catfile(curdir, 'Build'), 'test' ], build => 1, verbose => !$opts{silent}) or return 1;
 
 		my $sure = prompt('Do you want to continue the release process? y/n', 'n');
 		if (lc $sure eq 'y') {
@@ -171,7 +179,6 @@ my %actions = (
 			if ($opts{tag}) {
 				require Git::Wrapper;
 				my $git = Git::Wrapper->new('.');
-				say for $git->ls_files;
 				my $version = 'v' . $dist->version;
 				$git->tag('-m' => $version, $version);
 			}
@@ -192,13 +199,13 @@ my %actions = (
 		die "No arguments given to run\n" if not @arguments;
 		GetOptionsFromArray(\@arguments, 'build!' => \(my $build = 1)) or return 2;
 		my $dist = App::ModuleBuildTiny::Dist->new();
-		return $dist->run(command => \@arguments, build => $build);
+		return $dist->run(command => \@arguments, build => $build, verbose => 1);
 	},
 	shell => sub {
 		my @arguments = @_;
 		GetOptionsFromArray(\@arguments, 'build!' => \my $build) or return 2;
 		my $dist = App::ModuleBuildTiny::Dist->new();
-		return $dist->run(command => [ $SHELL ], build => $build);
+		return $dist->run(command => [ $SHELL ], build => $build, verbose => 0);
 	},
 	listdeps => sub {
 		my @arguments = @_;
@@ -250,7 +257,10 @@ my %actions = (
 			require Git::Wrapper;
 			my $git = Git::Wrapper->new('.');
 			my @files = keys %files;
-			push @files, 'lib' if $opts{bump};
+			if ($opts{bump}) {
+				push @files, 'lib';
+				push @files, 'script' if -d 'script';
+			}
 			my $allowed = join '|', map qr{^\Q$_\E$}, @files;
 			my @modified = grep /$allowed/, $git->ls_files({ modified => 1 });
 
